<?php

/**
 * WebService Miriade.ephemph - ephemerides physiques des SSO
 *   NameSpace : http://vo.imcce.fr/webservices/miriade/
 *   WSDL      : http://vo.imcce.fr/webservices/miriade/miriade.wsdl
 *   Method    : ephemph
 *   Parameters:  name     -> Number or name or designation of the target (with or not leading code 'a', 'p', 's', 'c')
 *                type     -> Optionnal input which allows to define the type of the target (aster, planet, satel, comet)
 *                ep       -> Starting date of ephemeris computation, expressed as Julian day or ISODate with or without the 'T'
 *                nbd      -> Number of date of ephemeris to compute
 *                step     -> Step of increment expressed in (d)ays or (h)ours or (m)inutes or (s)econds
 *                so       -> Spin axis solution number (in APDT)
 *                observer -> Location of the observer (500: geocenter (def.), ...)
 *                mime     -> Output format ('votable' or 'text' or 'html' or 'image')
 *                view     -> Output image format (fits, png, ps, none)
 *                rv       -> Compute radial velocity or not (0, 1)
 *                anim     -> Mode animate, draw the images for each date, else draw image only for the first date (0, 1)
 *                print    -> Display ephemeris results or not (0, 1)
 *                options  -> Options a passer au programme IDL 'visu' 
 *   Response  : Physical ephemeris of the requested SSO
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F.Vachier (IMCCE/OBSPM) <fv@imcce.fr>
 * @copyright (C) 2005-2017, IMCCE
 * @since PHP5
 * @version 2.0
 */

// Client's ID
$from = 'DemoClient';

// Parametres du service
$param = array(
   'name'    => 'a:pallas',
   'type'    => '',
   'epoch'   => 'now',
   'nbd'     => 5,
   'step'    => 1,
   'so'      => 1,
   'observer'=> '500',
   'mime'    => 'text',
   'view'    => 'png',
   'rv'      => false,
   'anim'    => false,
   'print'   => true,
   'options' => ''
);

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 1);

// Namespace et WSDL du service
$uri     = 'http://vo.imcce.fr/webservices/miriade';
$wsdl    = 'miriade.wsdl';
$uriwsdl = $uri."/".$wsdl;

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($uriwsdl, array('exceptions'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($uri, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall('ephemph',array($param));
  // Affichage du resultat
  if (! empty($param['get']))
  {
    switch ($param['mime']) {
      case 'text':
        $contentType = "Content-Type: text/plain";
        break;
      case 'text/csv':
        $contentType = "Content-Type: text/csv";
        break;
      case 'json':
        $contentType = "Content-Type: application/json";
        break;
      case 'votable':
        $contentType = "Content-Type: text/xml;content=x-votable";
        break;
    }
    header("HTTP/1.0 ".$response->status);
    header($contentType);
    echo $response->result."\n";
  }
  else
  {
    // Affichage du resultat
    if ($param['mime'] == 'text')
    {
      $res = explode(';', $response->result);
      $nbr = count($res);
      $newkey = array_keys($res);
      header("HTTP/1.0 ".$response->status);
      header("Content-Type: text/plain");
      echo "# Flag: ".$response->flag."\n";
      echo "# Ticket: ".$response->ticket."\n";
      for ($i=0; $i<$nbr; $i++) { echo $res[$newkey[$i]],"\n"; }
    }
    else if ($param['mime'] == 'image')
    {
      if ($response->flag == 1) {
        switch ($param['view']) {
          case "fits":
          case "psv:fits":
            $content = "image/fits";
            break;
          case "png":
          case "psv:png":
          case "wired:png":
            $content = "image/png";
            break;
          case "eps":
          case "wired:eps":
            $content = "application/postscript";
            break;
        }
        header("HTTP/1.0 ".$response->status);
        header("Content-Type: ".$content);
        echo file_get_contents($response->result);
      }
      else
      {
        header("HTTP/1.0 ".$response->status);
        header("Content-Type: text/xml;content=x-votable");
        echo $response->result."\n";
      }
    }
    else
    {
      header("HTTP/1.0 ".$response->status);
      header("Content-Type: text/xml;content=x-votable");
      echo $response->result."\n";
    }
  }
}
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
